from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePrivateKey

from jwt_smithy.file_saver import FileSaver


def _gen_private_key() -> EllipticCurvePrivateKey:
    return ec.generate_private_key(ec.SECP256R1())


def save_ecdsa_keys(directory: str):
    private_key = _gen_private_key()
    public_key = private_key.public_key()
    FileSaver(directory).save_key_pair(private_key, public_key)



from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives.asymmetric import rsa
from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey

from jwt_smithy.file_saver import FileSaver


def _gen_private_key() -> RSAPrivateKey:
    return rsa.generate_private_key(
        public_exponent=65537, key_size=2048, backend=default_backend()
    )


def save_rsa_keys(directory: str):
    private_key = _gen_private_key()
    public_key = private_key.public_key()
    FileSaver(directory).save_key_pair(private_key, public_key)



import typer

from jwt_smithy.ecdsa import save_ecdsa_keys
from jwt_smithy.rsa import save_rsa_keys
from jwt_smithy.shmac import save_shmac_keys

app = typer.Typer()


@app.command(name="rsa")
def rsa_command(directory: str = "rsa"):
    """
    Generate rs256 key pair in the given directory.
    """
    save_rsa_keys(directory)


@app.command(name="ecdsa")
def ecdsa_command(directory: str = "ecdsa"):
    """
    Generate ec256 key pair in the given directory.
    """
    save_ecdsa_keys(directory)


@app.command(name="shmac")
def shmac_command(directory: str = "shmac"):
    """
    Generate sh256 key in the given directory.
    """
    save_shmac_keys(directory)


if __name__ == "__main__":
    app()



import secrets

from jwt_smithy.file_saver import FileSaver


def _gen_key() -> str:
    return secrets.token_hex(256)


def save_shmac_keys(directory: str):
    key = _gen_key()
    FileSaver(directory).save_key_text("private.txt", key)



from pathlib import Path

from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePrivateKey, EllipticCurvePublicKey
from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey, RSAPublicKey

PRIVATE_KEY_TYPES = EllipticCurvePrivateKey | RSAPrivateKey
PUBLIC_KEY_TYPES = EllipticCurvePublicKey | RSAPublicKey
KEY_TYPES = PRIVATE_KEY_TYPES | PUBLIC_KEY_TYPES | str


class FileSaver:
    def __init__(self, directory: str):
        self.directory = directory

    def save_key_pair(
            self,
            private_key: PRIVATE_KEY_TYPES,
            public_key: PUBLIC_KEY_TYPES
    ):
        self.save_private_key("private.pem", private_key)
        self.save_public_key("public.pem", public_key)

    def save_private_key(
            self,
            key_name: str,
            key: PRIVATE_KEY_TYPES
    ):
        self.save_key(key_name, key.private_bytes(
            encoding=serialization.Encoding.PEM,
            format=serialization.PrivateFormat.TraditionalOpenSSL,
            encryption_algorithm=serialization.NoEncryption()))

    def save_public_key(
            self,
            key_name: str,
            key: PUBLIC_KEY_TYPES
    ):
        self.save_key(key_name, key.public_bytes(
            encoding=serialization.Encoding.PEM,
            format=serialization.PublicFormat.SubjectPublicKeyInfo,
        ))

    def save_key(self, key_name: str, key: bytes):
        self._create_dir_if_not_exists()
        with open(Path(self.directory) / key_name, "wb") as f:
            f.write(key)

    def save_key_text(self, key_name: str, key: str):
        self._create_dir_if_not_exists()
        with open(Path(self.directory) / key_name, "w") as f:
            f.write(key)

    def _create_dir_if_not_exists(self):
        Path(self.directory).mkdir(parents=True, exist_ok=True)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jwt_smithy']

package_data = \
{'': ['*']}

install_requires = \
['PyJWT[crypto]>=2.4.0,<3.0.0', 'typer[all]>=0.6.1,<0.7.0']

setup_kwargs = {
    'name': 'jwt-smithy',
    'version': '1.0.0',
    'description': 'Simple cli tool for jwt keys generation',
    'long_description': '# JWT smithy 🔨\n\n---\n\nSimple cli tool for jwt keys generation\n',
    'author': 'ilyakochankov',
    'author_email': 'ilyakochankov@yandex.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/KochankovID/jwt_smithy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
